@@ -1,14 +1,36 @@
 $(document).ready(function () {
   var slider_1 = document.getElementById("slider-1");
   var silder_value_1 = document.getElementById("value-1");
-
+  var slider_2 = document.getElementById("slider-2");
+  var silder_value_2 = document.getElementById("value-2");
   var menu = document.querySelector(".hamburger-menu");
   var bar = document.querySelector(".nav-bar");
+  $("svg").click(function () {
+    // console.log($(this));
+    var info = document.querySelector(".status");
+    info.classList.remove("animate1");
+    info.classList.remove("animate2");
+    var reload = document.querySelector("svg");
+    reload.classList.add("reload");
+    $.get("/refresh/analysis", function (data, textStatus, jqXHR) {
+      if (data == "Updated") {
+        $(".status").text("Already Updated");
+        info.classList.add("animate1");
+      } else {
+        location.reload();
+      }
 
+      // $(".status").text(null);
+      reload.classList.remove("reload");
+      // info.classList.remove("animate");
+    });
+  });
   slider_1.oninput = function () {
     silder_value_1.innerHTML = this.value;
   };
-
+  slider_2.oninput = function () {
+    silder_value_2.innerHTML = this.value;
+  };
   menu.addEventListener("click", () => {
     bar.classList.toggle("change");
   });
@@ -499,7 +521,7 @@ $(document).ready(function () {
             label: "Recovery Rate(R)",
             data: ylabel,
             backgroundColor: color,
-            barThickness: 15,
+            // barThickness: 15,
             borderColor: border,
             fill: false,
             borderWidth: 1,
@@ -536,7 +558,7 @@ $(document).ready(function () {
             label: "Deceased Rate(D)",
             data: ylabel,
             backgroundColor: color,
-            barThickness: 15,
+            // barThickness: 15,
             borderColor: border,
             fill: false,
             borderWidth: 1,
@@ -547,7 +569,107 @@ $(document).ready(function () {
       GetGraphData("horizontalBar", response, ctx, (id = 4));
     }
   );
+  $.get("/statistics/age_bar_chart", function (data, textStatus, jqXHR) {
+    console.log(data);
+    var xlabel = [];
+    var ylabel = [];
+    for (i = 0; i < data.length; i++) {
+      xlabel.push(Object.values(data[i])[0]);
+      ylabel.push(Object.values(data[i])[1]);
+    }
+    var response = {
+      labels: xlabel,
+      datasets: [
+        {
+          label: "Cases",
+          data: ylabel,
+          backgroundColor: "rgba(255, 0, 255,0.5)",
+          borderColor: "rgba(255, 0, 255,1)",
+          fill: false,
+          borderWidth: 1,
+        },
+      ],
+    };
+    var ctx = document.getElementById("graph-5").getContext("2d");
+    GetGraphData("bar", response, ctx, (id = 5));
+  });
+  $.post(
+    "/statistics/rolling_growth",
+    {
+      rolling: $("#slider-2").val(),
+    },
+    function (data, status, xhr) {
+      // console.log(data);
+      var xlabel = Object.keys(data[0]).slice(1);
+      var dataset = [];
+      window.color = [];
+      for (i = 0; i < data.length; i++) {
+        window.color.push(getRandomColor());
+        var tip = Object.values(data[i])[0];
+        var ylabel = Object.values(data[i]).slice(1);
+        var dict = {
+          label: tip,
+          data: ylabel,
+          backgroundColor: color[i],
+          borderColor: color[i],
+          fill: false,
+          borderWidth: 1,
+        };
+        dataset.push(dict);
+      }
+      var response = {
+        labels: xlabel,
+        datasets: dataset,
+      };
+      var ctx = document.getElementById("graph-6").getContext("2d");
+      GetGraphData("line", response, ctx, (id = 6));
+    }
+  );
+  $("#slider-2").change(function () {
+    $.post(
+      "/statistics/rolling_growth",
+      {
+        rolling: $("#slider-2").val(),
+      },
+      function (data, status, xhr) {
+        // console.log(data);
+        var xlabel = Object.keys(data[0]).slice(1);
+        var dataset = [];
+        for (i = 0; i < data.length; i++) {
+          // var color = getRandomColor();
+          var tip = Object.values(data[i])[0];
+          var ylabel = Object.values(data[i]).slice(1);
+          var dict = {
+            label: tip,
+            data: ylabel,
+            backgroundColor: window.color[i],
+            borderColor: window.color[i],
+            fill: false,
+            borderWidth: 1,
+          };
+          dataset.push(dict);
+        }
+        var response = {
+          labels: xlabel,
+          datasets: dataset,
+        };
+        // var ctx = document.getElementById("graph-6").getContext("2d");
+        // GetGraphData("line", response, ctx, (id = 6));
+        window.myChart6.data.labels = xlabel;
+        window.myChart6.data.datasets = dataset;
+        window.myChart6.update();
+      }
+    );
+  });
 });
+function getRandomColor() {
+  var letters = "0123456789ABCDEF";
+  var color = "#";
+  for (var i = 0; i < 6; i++) {
+    color += letters[Math.floor(Math.random() * 16)];
+  }
+  return color;
+}
 function GetGraphData(e, f, g, id) {
   if (id == 1) {
     if (window.myChart) window.myChart.destroy();
@@ -558,6 +680,8 @@ function GetGraphData(e, f, g, id) {
       type: e,
       data: f,
       options: {
+        responsive: true,
+        maintainAspectRatio: false,
         animation: {
           duration: 2000,
         },
@@ -579,7 +703,8 @@ function GetGraphData(e, f, g, id) {
           ],
         },
         tooltips: {
-          mode: "x",
+          mode: "index",
+          intersect: true,
         },
         legend: {
           display: true,
@@ -599,6 +724,8 @@ function GetGraphData(e, f, g, id) {
       type: e,
       data: f,
       options: {
+        responsive: true,
+        maintainAspectRatio: false,
         animation: {
           duration: 2000,
         },
@@ -620,7 +747,8 @@ function GetGraphData(e, f, g, id) {
           ],
         },
         tooltips: {
-          mode: "x",
+          mode: "index",
+          intersect: true,
         },
         legend: {
           display: true,
@@ -640,6 +768,8 @@ function GetGraphData(e, f, g, id) {
       type: e,
       data: f,
       options: {
+        responsive: true,
+        maintainAspectRatio: false,
         animation: {
           duration: 2000,
         },
@@ -654,8 +784,8 @@ function GetGraphData(e, f, g, id) {
           ],
           xAxes: [
             {
-              categoryPercentage: 1.0,
-              barPercentage: 0.5,
+              // categoryPercentage: 1.0,
+              // barPercentage: 0.5,
               ticks: {
                 fontColor: "rgba(255, 255, 255,0.5)",
               },
@@ -664,6 +794,7 @@ function GetGraphData(e, f, g, id) {
         },
         tooltips: {
           mode: "index",
+          intersect: true,
         },
         legend: {
           display: true,
@@ -683,6 +814,8 @@ function GetGraphData(e, f, g, id) {
       type: e,
       data: f,
       options: {
+        responsive: true,
+        maintainAspectRatio: false,
         animation: {
           duration: 2000,
         },
@@ -707,6 +840,7 @@ function GetGraphData(e, f, g, id) {
         },
         tooltips: {
           mode: "index",
+          intersect: true,
         },
         legend: {
           display: true,
@@ -717,4 +851,117 @@ function GetGraphData(e, f, g, id) {
       },
     });
   }
+  if (id == 5) {
+    if (window.myChart5) window.myChart5.destroy();
+    // var ctx = document.getElementById("graph").getContext("2d");
+    // console.log(window.myChart);
+
+    window.myChart5 = new Chart(g, {
+      type: e,
+      data: f,
+      options: {
+        responsive: true,
+        maintainAspectRatio: false,
+        animation: {
+          duration: 2000,
+        },
+        scales: {
+          yAxes: [
+            {
+              ticks: {
+                beginAtZero: true,
+                fontColor: "rgba(255, 255, 255,0.5)",
+              },
+            },
+          ],
+          xAxes: [
+            {
+              ticks: {
+                fontColor: "rgba(255, 255, 255,0.5)",
+              },
+            },
+          ],
+        },
+        tooltips: {
+          mode: "index",
+          intersect: true,
+        },
+        legend: {
+          display: true,
+          labels: {
+            fontColor: "rgba(255, 255, 255,0.8)",
+          },
+        },
+      },
+    });
+  }
+  if (id == 6) {
+    if (window.myChart6) window.myChart6.destroy();
+    // var ctx = document.getElementById("graph").getContext("2d");
+    // console.log(window.myChart);
+
+    window.myChart6 = new Chart(g, {
+      type: e,
+      data: f,
+      options: {
+        responsive: true,
+        maintainAspectRatio: false,
+        animation: {
+          duration: 2000,
+        },
+        scales: {
+          yAxes: [
+            {
+              ticks: {
+                beginAtZero: true,
+                fontColor: "rgba(255, 255, 255,0.5)",
+              },
+            },
+          ],
+          xAxes: [
+            {
+              ticks: {
+                fontColor: "rgba(255, 255, 255,0.5)",
+              },
+            },
+          ],
+        },
+        tooltips: {
+          mode: "index",
+          intersect: true,
+          yAlign: "bottom",
+        },
+        legend: {
+          display: true,
+          labels: {
+            fontColor: "rgba(255, 255, 255,0.8)",
+          },
+          onClick: function (e, legendItem) {
+            var index = legendItem.datasetIndex;
+            var ci = this.chart;
+            var alreadyHidden =
+              ci.getDatasetMeta(index).hidden === null
+                ? false
+                : ci.getDatasetMeta(index).hidden;
+
+            ci.data.datasets.forEach(function (e, i) {
+              var meta = ci.getDatasetMeta(i);
+
+              if (i !== index) {
+                if (!alreadyHidden) {
+                  meta.hidden = meta.hidden === null ? !meta.hidden : null;
+                } else if (meta.hidden === null) {
+                  meta.hidden = true;
+                }
+              } else if (i === index) {
+                meta.hidden = null;
+              }
+            });
+
+            ci.update();
+          },
+        },
+      },
+    });
+  }
 }
